==> mayan-edms-1.1.1.tar.gz: mayan-edms-1.1.1/mayan/apps/document_states/forms.py <==
from __future__ import unicode_literals

from django import forms
from django.utils.translation import ugettext_lazy as _

from common.forms import DetailForm

from .models import Workflow, WorkflowState, WorkflowInstance, WorkflowTransition


class WorkflowForm(forms.ModelForm):
    class Meta:
        fields = ('label',)
        model = Workflow


class WorkflowStateForm(forms.ModelForm):
    class Meta:
        fields = ('initial', 'label')
        model = WorkflowState


class WorkflowTransitionForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        workflow = kwargs.pop('workflow')
        super(WorkflowTransitionForm, self).__init__(*args, **kwargs)
        self.fields['origin_state'].queryset = self.fields['origin_state'].queryset.filter(workflow=workflow)
        self.fields['destination_state'].queryset = self.fields['destination_state'].queryset.filter(workflow=workflow)

    class Meta:
        fields = ('label', 'origin_state', 'destination_state')
        model = WorkflowTransition


class WorkflowInstanceTransitionForm(forms.Form):
    def __init__(self, *args, **kwargs):
        workflow = kwargs.pop('workflow')
        super(WorkflowInstanceTransitionForm, self).__init__(*args, **kwargs)
        self.fields['transition'].choices = workflow.get_transition_choices().values_list('pk', 'label')

    transition = forms.ChoiceField(label=_('Transition'))
    comment = forms.CharField(label=_('Comment'), required=False, widget=forms.widgets.Textarea())


class WorkflowInstanceDetailForm(DetailForm):
    class Meta:
        model = WorkflowInstance
        fields = ('workflow',)

==> mayan-edms-2.2b3.tar.gz: mayan-edms-2.2b3/mayan/apps/document_states/forms.py <==
from __future__ import absolute_import, unicode_literals

from django import forms
from django.utils.translation import ugettext_lazy as _

from .models import Workflow, WorkflowState, WorkflowTransition


class WorkflowForm(forms.ModelForm):
    class Meta:
        fields = ('label',)
        model = Workflow


class WorkflowStateForm(forms.ModelForm):
    class Meta:
        fields = ('initial', 'label', 'completion')
        model = WorkflowState


class WorkflowTransitionForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        workflow = kwargs.pop('workflow')
        super(WorkflowTransitionForm, self).__init__(*args, **kwargs)
        self.fields['origin_state'].queryset = self.fields['origin_state'].queryset.filter(workflow=workflow)
        self.fields['destination_state'].queryset = self.fields['destination_state'].queryset.filter(workflow=workflow)

    class Meta:
        fields = ('label', 'origin_state', 'destination_state')
        model = WorkflowTransition


class WorkflowInstanceTransitionForm(forms.Form):
    def __init__(self, *args, **kwargs):
        user = kwargs.pop('user')
        workflow_instance = kwargs.pop('workflow_instance')
        super(WorkflowInstanceTransitionForm, self).__init__(*args, **kwargs)
        self.fields[
            'transition'
        ].queryset = workflow_instance.get_transition_choices(_user=user)

    transition = forms.ModelChoiceField(
        label=_('Transition'), queryset=WorkflowTransition.objects.none()
    )
    comment = forms.CharField(
        label=_('Comment'), required=False, widget=forms.widgets.Textarea()
    )
